{{name}}
========
{{description}}

The directory structure is as follows:

* ./README.rst -- this file
* ./setup.py -- package installation parameters
* ./steelscript -- package source files files
* ./steelscript/{{name}}/core/ -- core source files
* ./steelscript/{{name}}/appfwk/plugin.py -- plugin information
* ./steelscript/{{name}}/appfwk/datasources/ - directory
* ./steelscript/{{name}}/appfwk/devices/ - directory of devices
* ./steelscript/{{name}}/appfwk/reports/ - directory of reports
* ./steelscript/{{name}}/appfwk/libs/ - helper functions
